@@ -65,7 +65,7 @@ def getbuilder(
 
     # Temporary stub (config volume will differ between containers)
     configvolume = ConfigVolume(dest='/etc/powny', files={
-        'powny.yaml': None,
+        'powny.yaml': YamlFile({}),
         'uwsgi.ini': TemplateFile(TextFile('uwsgi.ini')),
     })
 
@@ -110,7 +110,7 @@ def getbuilder(
             'rules': rules.dest,
             'logs': restapilogs.dest,
         },
-        command=stoppable('uwsgi --ini {}'.format(configvolume.getfilepath('uwsgi.ini'))),
+        command=stoppable('uwsgi --ini {}'.format(configvolume.files['uwsgi.ini'].fullpath)),
     )
 
     gitimage = SourceImage(
